@@ -1,7 +1,7 @@
 /* CatalystX::CRUD::YUI custom JavaScript 
 
 # sync with .pm files
-my $VERSION = '0.014';   
+my $VERSION = '0.015';   
 
 */
 YAHOO.namespace('crud');
@@ -293,8 +293,8 @@ YAHOO.crud.handle_crud_link_click = function(e) {
             var atag  = elTarget.getElementsByTagName('a')[0];
             var ahref = atag.getAttribute('href');
             var id;
-            if (ahref.match(/^#/)) {
-                id = ahref.match(/^#(.+)/)[1];
+            if (ahref.match(/#/)) {
+                id = ahref.match(/#(.+)/)[1];
             }
             else {
                 return true;
